==========
Procedure
==========

Procedure is a minimal process management system, capable of retrying and logging your tasks

Quick start
-----------

1. Add "procedure" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'procedure',
    ]

2. Run ``python manage.py migrate`` to create the Procedure models.
